'use client';
import { useAuth } from '@/components/context/auth';
import { useRouter } from 'next/navigation';
import { useEffect } from 'react';
import {
  AvatarUpload,
  ProfileForm,
  ResetPasswordForm,
  SignOut,
} from '@/components/default/profile';
import {
  Card,
  CardHeader,
  CardTitle,
  CardDescription,
  Separator,
} from '@/components/ui';
import { Loader2 } from 'lucide-react';
import { resetPassword } from '@/lib/actions';
import { toast } from 'sonner';
import { type Result } from '@/lib/actions';

const ProfilePage = () => {
  const {
    profile,
    isLoading,
    isAuthenticated,
    updateProfile,
    refreshUserData,
  } = useAuth();
  const router = useRouter();

  useEffect(() => {
    if (!isLoading && !isAuthenticated) {
      router.push('/sign-in');
    }
  }, [isLoading, isAuthenticated, router]);

  const handleAvatarUploaded = async (path: string) => {
    await updateProfile({ avatar_url: path });
    await refreshUserData();
  };

  const handleProfileSubmit = async (values: {
    full_name: string;
    email: string;
  }) => {
    try {
      await updateProfile({
        full_name: values.full_name,
        email: values.email,
      });
    } catch {
      toast.error('Error updating profile!: ');
    }
  };

  const handleResetPasswordSubmit = async (
    formData: FormData,
  ): Promise<Result<null>> => {
    try {
      const result = await resetPassword(formData);
      if (!result.success) {
        toast.error(`Error resetting password: ${result.error}`);
        return { success: false, error: result.error };
      }
      return { success: true, data: null };
    } catch (error) {
      toast.error(
        `Error resetting password!: ${(error as string) ?? 'Unknown error'}`,
      );
      return { success: false, error: 'Unknown error' };
    }
  };

  // Show loading state while checking authentication
  if (isLoading) {
    return (
      <div className='flex justify-center items-center min-h-[50vh]'>
        <Loader2 className='h-8 w-8 animate-spin text-gray-500' />
      </div>
    );
  }

  // If not authenticated and not loading, this will show briefly before redirect
  if (!isAuthenticated) {
    return (
      <div className='flex p-5 items-center justify-center'>
        <h1>Unauthorized - Redirecting...</h1>
      </div>
    );
  }

  return (
    <div className='max-w-2xl min-w-sm mx-auto p-4'>
      <Card className='mb-8'>
        <CardHeader className='pb-2'>
          <CardTitle className='text-2xl'>Your Profile</CardTitle>
          <CardDescription>
            Manage your personal information and how it appears to others
          </CardDescription>
        </CardHeader>
        {isLoading && !profile ? (
          <div className='flex justify-center py-8'>
            <Loader2 className='h-8 w-8 animate-spin text-gray-500' />
          </div>
        ) : (
          <div className='space-y-8'>
            <AvatarUpload onAvatarUploaded={handleAvatarUploaded} />
            <Separator />
            <ProfileForm onSubmit={handleProfileSubmit} />
            <Separator />
            <ResetPasswordForm onSubmit={handleResetPasswordSubmit} />
            <Separator />
            <SignOut />
          </div>
        )}
      </Card>
    </div>
  );
};

export default ProfilePage;
